@@ -308,7 +308,12 @@ class PixivExtractor(Extractor):
             square1200 = body["userIllusts"][body["id"]]["url"]
         except Exception:
             return
+
         parts = square1200.rpartition("_p0")[0].split("/")
+        if len(parts) < 6:
+            return self.log.warning(
+                "%s: %s", body["id"], square1200.rpartition("/")[2])
+
         del parts[3:5]
         parts[3] = "img-original"
         base = "/".join(parts)
@@ -424,14 +429,11 @@ class PixivArtworksExtractor(PixivExtractor):
         self.user_id = u1 or u2
         self.tag = t1 or t2
 
-        if self.sanity_workaround:
-            self.cookies_domain = domain = ".pixiv.net"
-            self._init_cookies()
-            if self._warn_phpsessid:
-                PixivArtworksExtractor._warn_phpsessid = False
-                if not self.cookies.get("PHPSESSID", domain=domain):
-                    self.log.warning("No 'PHPSESSID' cookie set. Can detect on"
-                                     "ly non R-18 'limit_sanity_level' works.")
+        if self.sanity_workaround and self._warn_phpsessid:
+            PixivArtworksExtractor._warn_phpsessid = False
+            if not self.cookies.get("PHPSESSID", domain=self.cookies_domain):
+                self.log.warning("No 'PHPSESSID' cookie set. Can detect only "
+                                 "non R-18 'limit_sanity_level' works.")
 
     def metadata(self):
         if self.config("metadata"):
@@ -441,19 +443,16 @@ class PixivArtworksExtractor(PixivExtractor):
     def works(self):
         works = self.api.user_illusts(self.user_id)
 
-        if self.sanity_workaround:
-            body = self._request_ajax(
-                f"/user/{self.user_id}/profile/all")
-            if not body:
-                return ()
+        if self.sanity_workaround and (body := self._request_ajax(
+                f"/user/{self.user_id}/profile/all")):
             try:
                 ajax_ids = list(map(int, body["illusts"]))
                 ajax_ids.extend(map(int, body["manga"]))
                 ajax_ids.sort()
             except Exception as exc:
+                self.log.debug("", exc_info=exc)
                 self.log.warning("u%s: Failed to collect artwork IDs "
-                                 "using AJAX API (%s: %s)",
-                                 self.user_id, exc.__class__.__name__, exc)
+                                 "using AJAX API", self.user_id)
             else:
                 works = self._extend_sanity(works, ajax_ids)
 
@@ -1252,9 +1251,9 @@ class PixivAppAPI():
             "/v1/user/bookmark-tags/illust", params, "bookmark_tags")
 
     @memcache(keyarg=1)
-    def user_detail(self, user_id):
+    def user_detail(self, user_id, fatal=True):
         params = {"user_id": user_id}
-        return self._call("/v1/user/detail", params)
+        return self._call("/v1/user/detail", params, fatal=fatal)
 
     def user_following(self, user_id, restrict="public"):
         params = {"user_id": user_id, "restrict": restrict}
@@ -1262,7 +1261,7 @@ class PixivAppAPI():
 
     def user_illusts(self, user_id):
         params = {"user_id": user_id}
-        return self._pagination("/v1/user/illusts", params)
+        return self._pagination("/v1/user/illusts", params, key_user="user")
 
     def user_novels(self, user_id):
         params = {"user_id": user_id}
@@ -1272,7 +1271,7 @@ class PixivAppAPI():
         params = {"illust_id": illust_id}
         return self._call("/v1/ugoira/metadata", params)["ugoira_metadata"]
 
-    def _call(self, endpoint, params=None, parse=None):
+    def _call(self, endpoint, params=None, parse=None, fatal=True):
         url = "https://app-api.pixiv.net" + endpoint
 
         while True:
@@ -1284,7 +1283,7 @@ class PixivAppAPI():
             else:
                 data = response.json()
 
-            if "error" not in data:
+            if "error" not in data or not fatal:
                 return data
 
             self.log.debug(data)
@@ -1297,22 +1296,31 @@ class PixivAppAPI():
                 self.extractor.wait(seconds=300)
                 continue
 
-            raise exception.AbortExtraction(f"API request failed: {error}")
+            msg = (f"'{msg}'" if (msg := error.get("user_message")) else
+                   f"'{msg}'" if (msg := error.get("message")) else
+                   error)
+            raise exception.AbortExtraction(f"API request failed: {msg}")
 
     def _pagination(self, endpoint, params,
-                    key_items="illusts", key_data=None):
-        while True:
-            data = self._call(endpoint, params)
+                    key_items="illusts", key_data=None, key_user=None):
+        data = self._call(endpoint, params)
 
-            if key_data:
-                self.data = data.get(key_data)
-                key_data = None
+        if key_data is not None:
+            self.data = data.get(key_data)
+        if key_user is not None and not data[key_user].get("id"):
+            user = self.user_detail(self.extractor.user_id, fatal=False)
+            if user.get("error"):
+                raise exception.NotFoundError("user")
+            return
+
+        while True:
             yield from data[key_items]
 
             if not data["next_url"]:
                 return
             query = data["next_url"].rpartition("?")[2]
             params = text.parse_query(query)
+            data = self._call(endpoint, params)
 
 
 @cache(maxage=36500*86400, keyarg=0)
