@@ -12,14 +12,14 @@ __tests__ = (
     "#url"     : "https://arch.b4k.dev/meta/thread/196/",
     "#category": ("foolfuuka", "b4k", "thread"),
     "#class"   : foolfuuka.FoolfuukaThreadExtractor,
-    "#urls"    : "https://arch.b4k.dev/media/meta/image/1481/33/14813348737492.jpg",
+    "#results" : "https://arch.b4k.dev/media/meta/image/1481/33/14813348737492.jpg",
 },
 
 {
     "#url"     : "https://arch.b4k.co/meta/thread/196/",
     "#category": ("foolfuuka", "b4k", "thread"),
     "#class"   : foolfuuka.FoolfuukaThreadExtractor,
-    "#urls"    : "https://arch.b4k.dev/media/meta/image/1481/33/14813348737492.jpg",
+    "#results" : "https://arch.b4k.dev/media/meta/image/1481/33/14813348737492.jpg",
 },
 
 {
