@@ -109,6 +109,11 @@ __tests__ = (
     "#class"   : instagram.InstagramStoriesExtractor,
 },
 
+{
+    "#url"     : "https://www.instagram.com/stories/me/",
+    "#class"   : instagram.InstagramStoriesTrayExtractor,
+},
+
 {
     "#url"     : "https://www.instagram.com/s/aGlnaGxpZ2h0OjE4MDQyNTA5NDg4MTcwMDk1",
     "#category": ("", "instagram", "highlights"),
